@@ -1,3 +1,5 @@
+# Copyright (C) Dnspython Contributors, see LICENSE for text of ISC license
+
 # Copyright (C) 2003-2007, 2009-2011 Nominum, Inc.
 #
 # Permission to use, copy, modify, and distribute this software and its
@@ -17,10 +19,13 @@
 
 __all__ = [
     'AFSDB',
+    'AVC',
+    'CAA',
     'CDNSKEY',
     'CDS',
     'CERT',
     'CNAME',
+    'CSYNC',
     'DLV',
     'DNAME',
     'DNSKEY',
@@ -37,7 +42,7 @@ __all__ = [
     'NSEC',
     'NSEC3',
     'NSEC3PARAM',
-    'TLSA',
+    'OPENPGPKEY',
     'PTR',
     'RP',
     'RRSIG',
@@ -45,6 +50,8 @@ __all__ = [
     'SOA',
     'SPF',
     'SSHFP',
+    'TLSA',
     'TXT',
+    'URI',
     'X25',
 ]
